<template>
    <TransitionGroup name="list" tag="div" class="custom-flashmessage">
        <div v-for="(flashMessage, index) in $store.state.flashMessages.slice().reverse()" :key="`flash-message${index}`">
            <div id="toast-container" class="toast-container toast-top-right">
                <div class="toast" v-bind:class="`toast-${flashMessage.variant}`" aria-live="polite">
                    <button type="button" class="toast-close-button" role="button"
                        v-on:click="hideToast(flashMessage)">×</button>
                    <div class="toast-title">{{ flashMessage.variant }}!</div>
                    <div class="toast-message">{{ flashMessage.message }}</div>
                </div>
            </div>
            {{ hideToastOnDelay(flashMessage) }}
        </div>
    </TransitionGroup>
</template>

<script>
import { useStore } from 'vuex';
export default {
    name: 'FlashMessage',
    setup() {
        const store = useStore();

        function hideToast(flashMessage) {
            // let index = store.state.flashMessages.indexOf(flashMessage);
            // store.state.flashMessages.splice(index, 1);
            // store.state.flashMessages.filter(fMessage => {
            //     return fMessage.id != flashMessage.id;
            // });

            store.state.flashMessages = store.state.flashMessages.filter(fMessage => {
                return fMessage.id != flashMessage.id;
            });
        }

        function hideToastOnDelay(flashMessage) {
            setTimeout(() => {
                store.state.flashMessages = store.state.flashMessages.filter(fMessage => {
                    return fMessage.id != flashMessage.id;
                });
                // let index = store.state.flashMessages.indexOf(flashMessage);
                // store.state.flashMessages.splice(index, 1);
            }, flashMessage.delay);
        }

        function showFlashMessage() {
            let random = Math.floor(Math.random() * 10000);
            store.state.flashMessages.push({
                id: random,
                variant: 'error',
                message: 'testing is listing ' + random,
                delay: 5000
            });
        }

        return {
            hideToast,
            hideToastOnDelay,
            showFlashMessage
        }
    }
}
</script>

<style scoped>
.list-enter-active,
.list-leave-active {
    transition: all 0.5s ease;
}

.list-enter-from,
.list-leave-to {
    opacity: 0;
    transform: translateX(30px);
}
</style>
